Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(21)

Unified Diff: extensions/renderer/bindings/api_bindings_system_unittest.h

Issue 2953133002: [Extensions Bindings] Support chrome.extension.lastError (Closed)
Patch Set: jbroman's, lazyboy's Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: extensions/renderer/bindings/api_bindings_system_unittest.h
diff --git a/extensions/renderer/bindings/api_bindings_system_unittest.h b/extensions/renderer/bindings/api_bindings_system_unittest.h
index d4510fc13794eb2883e0fc1f46857bcdb16848e8..2413eefd4323b2637ba27c0b35d91b4b393c363e 100644
--- a/extensions/renderer/bindings/api_bindings_system_unittest.h
+++ b/extensions/renderer/bindings/api_bindings_system_unittest.h
@@ -45,10 +45,13 @@ class APIBindingsSystemTest : public APIBindingTest {
// subclasses to return their own specifications.
virtual std::vector<FakeSpec> GetAPIs();
// Returns the object to be used as the parent for the `lastError`. The
// default returns an empty JS object (assumes no last errors will be set).
virtual v8::Local<v8::Object> GetLastErrorParent(
- v8::Local<v8::Context> context);
+ v8::Local<v8::Context> context,
+ v8::Local<v8::Object>* secondary_parent);
// Returns the DictionaryValue representing the schema with the given API
// name.
@@ -45,10 +45,13 @@ class APIBindingsSystemTest : public APIBindingTest {
// subclasses to return their own specifications.
virtual std::vector<FakeSpec> GetAPIs();
- // Returns the object to be used as the parent for the `lastError`. The
- // default returns an empty JS object (assumes no last errors will be set).
+ // Returns the object to be used as the parent for the `lastError`, and,
+ // optionally, the secondary parent. The default returns an empty JS object
+ // and does not populate |secondary_parent| (assumes no last errors will be
+ // set).
virtual v8::Local<v8::Object> GetLastErrorParent(

Powered by Google App Engine
This is Rietveld 408576698